@@ -31,7 +31,7 @@ class Distro(Module):
         target.send(pub, full)
 
         ok = distro.file(
-            full, mod='600', usr=usr, grp=user.group.name
+            full, mode='600', user=usr, group=user.group.name
         ).deploy()
 
         return ok
