@@ -8,21 +8,25 @@ class Distro(Module):
     '''
     def deploy(self, target, **kw):
         user = target.login.name
-        os = target.os
+        kernel = target.kernel
         python = target.run('python3 -V')[1][0]
-        host = target.distro.host
+        sys = target.distro.system
+        try:
+            addr = target.net.addr
+        except:
+            addr = '!'
 
         inst = '-' #len(list(target.Package.installed()))
-        avail = '-' #len(list(target.Package.available()))
+        avail = '-' #len(list(target.Package.installable()))
         #packages : {inst} / {avail}
 
         infos =  f'''
         target : {target}
         distro : {target.distro.name}
         python : {python}
-        os     : {os.kernel} {os.version} / {os.arch}
+        os     : {kernel.name} {kernel.version} / {kernel.arch}
         user   : {user}
-        host   : {host.name} : {host.addr}
+        host   : {sys.hostname} : {addr}
         setux  : {__version__}
         '''
 
