@@ -14,14 +14,17 @@ class Distro(Module):
 
         if src:
             sre = compile(src).search
-            updated =[]
+            updated, done = [], False
             for line in cont.split('\n'):
                 if sre(line):
                     msg.append(f' <  {line}')
                     msg.append(f'  > {dst}')
                     updated.append(dst)
+                    done = True
                 else:
                     updated.append(line)
+            if not done:
+                updated.append(dst)
             target.write(cfg, '\n'.join(updated)+'\n', report='quiet')
         else:
             msg.append(f'  > {dst}')
